bwe_feedback_policy

Function bwe_feedback_policy 

fn bwe_feedback_policy(
    header_extensions: &[HeaderExtension],
) -> BweFeedbackPolicy
Selects a local forwarding policy for mutually exclusive bandwidth-estimation feedback families.

Resolves conflicting congestion control feedback modes by removing feedback only:

  • if transport-wide CC is available, prefer transport-cc and strip goog-remb
  • otherwise, if abs-send-time is available, prefer goog-remb and strip transport-cc
  • otherwise strip both feedback families
               Negotiated Header Extensions
                            |
           +----------------+----------------+
           |                                 |
  Contains TWCC extension?          Otherwise abs-send-time?
           |                                 |
           v (yes)                           v (yes)
 [ PreferTransportCc ]              [ PreferGoogRemb ]
           |                                 |
           v                                 v
 - Keep `transport-cc` feedback     - Keep `goog-remb` feedback
 - Strip conflicting `goog-remb`    - Strip `transport-cc`

If neither extension is present, BweFeedbackPolicy::DisableBoth strips both families.