normalized_channels

Function normalized_channels 

fn normalized_channels(
    media_kind: MediaKind,
    channels: Option<u16>,
) -> Option<u16>
Channel count is only part of codec identity for audio. Video formats do not use RTP channel count semantics in this model, so we normalize all video channel counts away to avoid spurious mismatches.